# -*- coding: utf-8 -*-

from django.apps import AppConfig


class OrganizationsConfig(AppConfig):
    name = "organizations"
    verbose_name = "Organizations"
    default_auto_field = 'django.db.models.AutoField'
