{% extends "organizations_base.html" %}
{% load i18n %}
{% block content %}
<h1> {{ organization_user }} @ {{ organization }}</h1>
{% if user == organization_user.user %}{% trans "This is you" %}!{% endif %}
<ul>
	<li>{% trans "Name" %}: {{ organization_user.full_name }}</li>
	<li>{% trans "Email" %}: {{ organization_user.user.email }}</li>
</ul>
<ul>
	<li><a href="{% url "organization_user_edit" organization.pk organization_user.user.pk %}">{% trans "Edit" %}</a></li>
	<li><a href="{% url "organization_user_delete" organization.pk organization_user.user.pk %}">{% trans "Delete" %}</a></li>
</ul>
{% endblock %}
