{% extends "organizations_base.html" %}
{% load i18n %}
{% load org_tags %}
{% block content %}
<h1>{{ organization }}</h1>
<ul>
	<li><a href="{% url "organization_edit" organization.pk %}">{% trans "Edit" %}</a></li>
	<li><a href="{% url "organization_delete" organization.pk %}">{% trans "Delete" %}</a></li>
	<li><a href="{% url "organization_user_add" organization.pk %}">{% trans "Add a member" %}</a></li>
</ul>
{% organization_users organization %}
{% endblock %}

